#--------------------------------------------------------------------------
## Kelp connectivity in Chile
## Filename: ENSO_stats.R
## Description:Script with the stats of the network analysis over time - ENSO 
#--------------------------------------------------------------------------

library(mgcv)
library(performance)


###Instrength

load("in_strength_nodes_enso")

in_strength_nodes_enso$node <- as.numeric(in_strength_nodes_enso$node)
in_strength_nodes_enso$TIME <- as.factor(in_strength_nodes_enso$TIME)

summary(in_strength_nodes_enso$instrength)
hist(in_strength_nodes_enso$instrength)

mod_in_strength <- gam(instrength ~ TIME + s(node, bs = "re"),
                       data = in_strength_nodes_enso, method = "ML",
                       family = Gamma(link = "log"))

summary(mod_in_strength)
check_overdispersion(mod_in_strength)
check_autocorrelation(mod_in_strength)
model_performance(mod_in_strength)


###outstrength

load("out_strength_nodes_enso")

out_strength_nodes_enso$node <- as.numeric(out_strength_nodes_enso$node)
out_strength_nodes_enso$TIME <- as.factor(out_strength_nodes_enso$TIME)

summary(out_strength_nodes_enso$outstrength)


mod_out_strength <- gam(outstrength ~ TIME + s(node, bs = "re"),
                        data = out_strength_nodes_enso, method = "ML",
                        family = Gamma(link = "log"))

summary(mod_out_strength)
check_overdispersion(mod_out_strength)
check_autocorrelation(mod_out_strength)
model_performance(mod_out_strength)


###Degree

load("degree_nodes_enso")

degree_nodes_enso$node <- as.numeric(degree_nodes_enso$node)
degree_nodes_enso$TIME <- as.factor(degree_nodes_enso$TIME)

summary(degree_nodes_enso$degree)

mod_degree <- gam(degree ~ TIME + s(node, bs = "re"),
                  data = degree_nodes_enso, method = "ML",
                  family = gaussian())

summary(mod_degree)
check_overdispersion(mod_degree)
check_autocorrelation(mod_degree)
model_performance(mod_degree)


###eigenvector

load("eigenvector_nodes_enso")

eigenvector_nodes_enso$node <- as.numeric(eigenvector_nodes_enso$node)
eigenvector_nodes_enso$TIME <- as.factor(eigenvector_nodes_enso$TIME)

summary(eigenvector_nodes_enso$eigenvector)

mod_eigenvector <- gam(eigenvector ~ TIME + s(node, bs = "re"),
                       data = eigenvector_nodes_enso, method = "ML",
                       family = Gamma(link = "log"))

summary(mod_eigenvector)
check_overdispersion(mod_eigenvector)
check_autocorrelation(mod_eigenvector)
model_performance(mod_eigenvector)


###closeness

load("closeness_nodes_enso")

closeness_nodes_enso$node <- as.numeric(closeness_nodes_enso$node)
closeness_nodes_enso$TIME <- as.factor(closeness_nodes_enso$TIME)

summary(closeness_nodes_enso$closeness)

mod_closeness <- gam(closeness ~ TIME + s(node, bs = "re"),
                     data = closeness_nodes_enso, method = "ML",
                     family = Gamma(link = "log"))

summary(mod_closeness)
check_overdispersion(mod_closeness)
check_autocorrelation(mod_closeness)
model_performance(mod_closeness)


###local retention

load("local_retention_nodes_enso")

local_retention_nodes_enso$node <- as.numeric(local_retention_nodes_enso$node)
local_retention_nodes_enso$TIME <- as.factor(local_retention_nodes_enso$TIME)

summary(local_retention_nodes_enso$localretention)

mod_localretention <- gam(localretention ~ TIME + s(node, bs = "re"),
                          data = local_retention_nodes_enso, method = "ML",
                          family = Gamma(link = "log"))

summary(mod_localretention)
check_overdispersion(mod_localretention)
check_autocorrelation(mod_localretention)
model_performance(mod_localretention)



###non-local retention

load("non_local_retention_nodes_enso")

non_local_retention_nodes_enso$node <- as.numeric(non_local_retention_nodes_enso$node)
non_local_retention_nodes_enso$TIME <- as.factor(non_local_retention_nodes_enso$TIME)

summary(non_local_retention_nodes_enso$non_localretention)

mod_non_localretention <- gam(non_localretention ~ TIME + s(node, bs = "re"),
                              data = non_local_retention_nodes_enso, method = "ML",
                              family = Gamma(link = "log"))

summary(mod_non_localretention)
check_overdispersion(mod_non_localretention)
check_autocorrelation(mod_non_localretention)
model_performance(mod_non_localretention)
