#--------------------------------------------------------------------------
## Kelp connectivity in Chile
## Filename: Season_stats.R
## Description:Script with the stats of the network analysis over time - season 
#--------------------------------------------------------------------------

library(mgcv)
library(performance)

###Instrength

load("in_strength_nodes_season")

in_strength_nodes_season$node <- as.numeric(in_strength_nodes_season$node)
in_strength_nodes_season$TIME <- as.factor(in_strength_nodes_season$TIME)

summary(in_strength_nodes_season$instrength)

mod_instrength <- gam(instrength ~ TIME + s(node, bs = "re"),
                      data = in_strength_nodes_season, method = "ML",
                      family = Gamma(link = "log"))

summary(mod_instrength)
check_overdispersion(mod_instrength)
check_autocorrelation(mod_instrength)
model_performance(mod_instrength) 


###outstrength

load("out_strength_nodes_season")

out_strength_nodes_season$node <- as.numeric(out_strength_nodes_season$node)
out_strength_nodes_season$TIME <- as.factor(out_strength_nodes_season$TIME)

summary(out_strength_nodes_season$outstrength)

mod_outstrength <- gam(outstrength ~ TIME + s(node, bs = "re"),
                       data = out_strength_nodes_season, method = "ML",
                       family = Gamma(link = "log"))

summary(mod_outstrength)
check_overdispersion(mod_outstrength)
check_autocorrelation(mod_outstrength)
model_performance(mod_outstrength) 


###Degree

load("degree_nodes_season")

degree_nodes_season$node <- as.factor(degree_nodes_season$node)
degree_nodes_season$TIME <- numeric(degree_nodes_season$TIME)

summary(degree_nodes_season$degree)

mod_degree <- gam(degree ~ TIME + s(node, bs = "re"),
                  data = degree_nodes_season, method = "ML",
                  family = Gamma(link = "log"))

summary(mod_degree)
check_overdispersion(mod_degree)
check_autocorrelation(mod_degree)
model_performance(mod_degree)



###eigenvector

load("eigenvector_nodes_season")

eigenvector_nodes_season$node <- as.numeric(eigenvector_nodes_season$node)
eigenvector_nodes_season$TIME <- as.factor(eigenvector_nodes_season$TIME)

summary(eigenvector_nodes_season$eigenvector)

mod_eigenvector <- gam(eigenvector ~ TIME + s(node, bs = "re"),
                       data = eigenvector_nodes_season, method = "ML",
                       family = Gamma(link = "log"))

summary(mod_eigenvector)
check_overdispersion(mod_eigenvector)
check_autocorrelation(mod_eigenvector)
model_performance(mod_eigenvector)



###closeness

load("closeness_nodes_season")

closeness_nodes_season$node <- as.numeric(closeness_nodes_season$node)
closeness_nodes_season$TIME <- as.factor(closeness_nodes_season$TIME)

summary(closeness_nodes_season$closeness)

mod_closeness <- gam(closeness ~ TIME + s(node, bs = "re"),
                     data = closeness_nodes_season, method = "ML",
                     family = Gamma(link = "log"))

summary(mod_closeness)
check_overdispersion(mod_closeness)
check_autocorrelation(mod_closeness)
model_performance(mod_closeness)



###local retention

load("local_retention_nodes_season")

local_retention_nodes_season$node <- as.numeric(local_retention_nodes_season$node)
local_retention_nodes_season$TIME <- as.factor(local_retention_nodes_season$TIME)

summary(local_retention_nodes_season$localretention)


mod_localretention <- gam(localretention ~ TIME + s(node, bs = "re"),
                          data = local_retention_nodes_season, method = "ML",
                          family = Gamma(link = "log"))

summary(mod_localretention)
check_overdispersion(mod_localretention)
check_autocorrelation(mod_localretention)
model_performance(mod_localretention)



###non-local retention

load("non_local_retention_nodes_season")

non_local_retention_nodes_season$node <- as.numeric(non_local_retention_nodes_season$node)
non_local_retention_nodes_season$TIME <- as.factor(non_local_retention_nodes_season$TIME)

summary(non_local_retention_nodes_season$non_localretention)

mod_non_localretention <- gam(non_localretention ~ TIME + s(node, bs = "re"),
                              data = non_local_retention_nodes_season, method = "ML",
                              family = Gamma(link = "log"))

summary(mod_non_localretention)
check_overdispersion(mod_non_localretention)
check_autocorrelation(mod_non_localretention)
model_performance(mod_non_localretention)
